@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.15';
+$VERSION = '5.16';
 
 =head1 NAME
 
@@ -35,6 +35,8 @@ used within the framework to provide error, debugging and trace information.
 
 =head1 EXPORT
 
+  DumpToFile
+
   SetLogFile
   LogRecord
 
@@ -60,6 +62,7 @@ require Exporter;
 
 %EXPORT_TAGS = (
     'all' => [ qw(
+        DumpToFile
         SetLogFile LogRecord
         LogError LogWarning LogInfo LogDebug
         $LOG_LEVEL_DEBUG $LOG_LEVEL_INFO
@@ -106,6 +109,21 @@ Audit Log functions enable tracing of actions for a user at a given time.
 
 =over 4
 
+=item DumpToFile($file,@blocks)
+
+Writes blocks (separated by new lines) to the given file. Creates the file if
+it doesn't exist, and overwrites if it does.
+
+=cut
+
+sub DumpToFile {
+    my $file = shift;
+
+    my $fh = IO::File->new($file, 'w+') or return;
+    print $fh join("\n",@_) . "\n";
+    $fh->close;
+}
+
 =item SetLogFile(%hash)
 
 Hash table entries can be as follows:
